# huetainment-api
huetainment API

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import huetainment_api 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import huetainment_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import huetainment_api
from huetainment_api.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = huetainment_api.SettingsApi(huetainment_api.ApiClient(configuration))

try:
    # Get Settings
    api_response = api_instance.get_settings()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SettingsApi->get_settings: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://virtserver.swaggerhub.com/Semperpax/huetainment/1.0.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SettingsApi* | [**get_settings**](docs/SettingsApi.md#get_settings) | **GET** /settings | Get Settings
*SettingsApi* | [**set_settings**](docs/SettingsApi.md#set_settings) | **PUT** /settings | Set settings
*StatesApi* | [**get_states**](docs/StatesApi.md#get_states) | **GET** /states | Get states
*StatesApi* | [**set_states**](docs/StatesApi.md#set_states) | **PUT** /states | Set states


## Documentation For Models

 - [SettingCaptureDevice](docs/SettingCaptureDevice.md)
 - [SettingCaptureInterval](docs/SettingCaptureInterval.md)
 - [SettingCaptureMargins](docs/SettingCaptureMargins.md)
 - [SettingCaptureMultiplier](docs/SettingCaptureMultiplier.md)
 - [SettingCaptureVideoStandard](docs/SettingCaptureVideoStandard.md)
 - [SettingCenterSlowness](docs/SettingCenterSlowness.md)
 - [SettingChromaBoost](docs/SettingChromaBoost.md)
 - [SettingColorBias](docs/SettingColorBias.md)
 - [SettingLumaBoost](docs/SettingLumaBoost.md)
 - [SettingMaxLuminance](docs/SettingMaxLuminance.md)
 - [SettingMinLuminance](docs/SettingMinLuminance.md)
 - [SettingSideSlowness](docs/SettingSideSlowness.md)
 - [SettingSyncingGroup](docs/SettingSyncingGroup.md)
 - [Settings](docs/Settings.md)
 - [StateCapturing](docs/StateCapturing.md)
 - [StateSyncing](docs/StateSyncing.md)
 - [States](docs/States.md)


## Documentation For Authorization

 All endpoints do not require authorization.


## Author

cbro@semperpax.com

